==> ejc-jltest-api-3.0.0-20240311.003427-52-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangeraDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细A
 * 
 * @author generator
 * 
 */
public class DangeraDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long dangeraId; // 主表主键ID
    private String detailCode; // 隐患编号
    private Integer detailCategory; // 类别
    private String detailManage; // 管理环节
    private String hiddenTrouble; // 隐患内容
    private String selfExamination; // 自查情况
    private String judgmentResults; // 判定结果
    private String detailMemo; // 备注
    

    public Long getDangeraId() {
        return dangeraId;
    }

    public void setDangeraId(Long dangeraId) {
        this.dangeraId = dangeraId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    public Integer getDetailCategory() {
        return detailCategory;
    }

    public void setDetailCategory(Integer detailCategory) {
        this.detailCategory = detailCategory;
    }
    public String getDetailManage() {
        return detailManage;
    }

    public void setDetailManage(String detailManage) {
        this.detailManage = detailManage;
    }
    public String getHiddenTrouble() {
        return hiddenTrouble;
    }

    public void setHiddenTrouble(String hiddenTrouble) {
        this.hiddenTrouble = hiddenTrouble;
    }
    public String getSelfExamination() {
        return selfExamination;
    }

    public void setSelfExamination(String selfExamination) {
        this.selfExamination = selfExamination;
    }
    public String getJudgmentResults() {
        return judgmentResults;
    }

    public void setJudgmentResults(String judgmentResults) {
        this.judgmentResults = judgmentResults;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}

==> ejc-jltest-api-3.0.0-20240328.061255-140-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangeraDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细A
 * 
 * @author generator
 * 
 */
public class DangeraDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long dangeraId; // 主表主键ID
    private String detailCode; // 隐患编号
    private Long detailCategory; // 类别
    private String detailManage; // 管理环节
    private String hiddenTrouble; // 隐患内容
    private String selfExamination; // 自查情况
    private String judgmentResults; // 判定结果
    private String detailMemo; // 备注
    

    public Long getDangeraId() {
        return dangeraId;
    }

    public void setDangeraId(Long dangeraId) {
        this.dangeraId = dangeraId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }

    public Long getDetailCategory() {
        return detailCategory;
    }

    public void setDetailCategory(Long detailCategory) {
        this.detailCategory = detailCategory;
    }

    public String getDetailManage() {
        return detailManage;
    }

    public void setDetailManage(String detailManage) {
        this.detailManage = detailManage;
    }
    public String getHiddenTrouble() {
        return hiddenTrouble;
    }

    public void setHiddenTrouble(String hiddenTrouble) {
        this.hiddenTrouble = hiddenTrouble;
    }
    public String getSelfExamination() {
        return selfExamination;
    }

    public void setSelfExamination(String selfExamination) {
        this.selfExamination = selfExamination;
    }
    public String getJudgmentResults() {
        return judgmentResults;
    }

    public void setJudgmentResults(String judgmentResults) {
        this.judgmentResults = judgmentResults;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}
